@@ -2,9 +2,10 @@ __all__ = ['Context']
 
 from otools.logging.Logger import Logger
 from otools.logging.LoggingLevel import LoggingLevel
-from otools.core.Tool import Tool
+from otools.core.Service import Service
 from otools.core.Dataframe import Dataframe
 from otools.status.StatusCode import StatusCode
+import threading
 
 class Context ():
   """
@@ -17,7 +18,7 @@ class Context ():
     self._name = name
     self._logger = Logger(level).getModuleLogger()
     self.info("Context with name {} created successfully!".format(self.name))
-    self._tools = {}
+    self._services = {}
     self._services = {}
     self._dataframes = {}
     self._active = True
@@ -30,14 +31,14 @@ class Context ():
     return self.__str__()
 
   def __add__ (self, obj):
-    if issubclass(type(obj), Tool):
-      if obj.name in self._tools:
-        message = "Tool with name {} already attached, skipping...".format(obj.name)
+    if issubclass(type(obj), Service):
+      if obj.name in self._services:
+        message = "Service with name {} already attached, skipping...".format(obj.name)
         self.warning(message, self.__str__())
         return self
-      self.info (" * Adding Tool with name {}...".format(obj.name))
+      self.info (" * Adding Service with name {}...".format(obj.name))
       obj.setContext(self)
-      self._tools[obj.name] = obj
+      self._services[obj.name] = obj
     elif issubclass(type(obj), Dataframe):
       if obj.name in self._dataframes:
         message = "Dataframe with name {} already attached, skipping...".format(obj.name)
@@ -48,11 +49,11 @@ class Context ():
       self._dataframes[obj.name] = obj
     return self
 
-  def getTool (self, toolName):
-    if toolName in self._tools:
-      return self._tools[toolName]
+  def getService (self, serviceName):
+    if serviceName in self._services:
+      return self._services[serviceName]
     else:
-      message = "Tool with name {} is not attached into this context!".format(toolName)
+      message = "Service with name {} is not attached into this context!".format(serviceName)
       self.error(message, self.__str__())
       return None
 
@@ -90,27 +91,35 @@ class Context ():
   def fatal (self, message, moduleName="Unknown", contextName="Unknown", *args, **kws):
     self._logger.fatal(message, moduleName, self.name, *args, **kws)
 
-  def initialize (self):
-    for tool in self._tools:
-      if self._tools[tool].initialize().isFailure():
-        message = "Failed to initialize tool {}".format(tool)
+  def setup (self):
+    for service in self._services:
+      if self._services[service].setup().isFailure():
+        message = "Failed to setup service {}".format(service)
         self.fatal(message, self.__str__())
         return StatusCode.FAILURE
     return StatusCode.SUCCESS
 
-  def execute (self):
-    for tool in self._tools:
-      if self._tools[tool].execute().isFailure():
-        message = "Failed to execute tool {}".format(tool)
+  def main (self):
+    for service in self._services:
+      if self._services[service].main().isFailure():
+        message = "Failed to main service {}".format(service)
         self.fatal(message, self.__str__())
         return StatusCode.FAILURE
     return StatusCode.SUCCESS
 
+  def loop (self):
+    for service in list(self._services):
+      if self._services[service].active:
+        loop_thread = threading.Thread(target=self._services[service].loop, args=())
+        loop_thread.name = "{}_loop".format(service)
+        loop_thread.daemon = True
+        loop_thread.start()
+
   def finalize (self):
     self._active = False
-    for tool in self._tools:
-      if self._tools[tool].finalize().isFailure():
-        message = "Failed to finalize tool {}".format(tool)
+    for service in self._services:
+      if self._services[service].finalize().isFailure():
+        message = "Failed to finalize service {}".format(service)
         self.fatal(message, self.__str__())
         return StatusCode.FAILURE
     return StatusCode.SUCCESS
